# -*- coding: utf-8 -*-

from pysankey import sankey
from pysankey import LabelMismatch, NullsInFrame
from pysankey.tests.generic_test import TestFruit


class TestErrorCase(TestFruit):

    """ Test sankey's error case. """

    def test_bad_color_labels(self):
        """ sankey raise a value error when there is not enough color info"""
        bad_color_dict = {"apple": "#f71b1b", "orange": "#f78c1b"}
        with self.assertRaises(ValueError) as value_error:
            sankey(self.data["true"], self.data["predicted"], colorDict=bad_color_dict)
        self.assertIn(": lime, blueberry, banana, kiwi", str(value_error.exception))

    def test_label_mismatch(self):
        """ sankey raises a LabelMismatch when data doesn't match the labels"""
        with self.assertRaises(LabelMismatch):
            sankey(
                self.data["true"],
                self.data["predicted"],
                leftLabels=["banana", "orange", "blueberry", "apple", "lime"],
                rightLabels=["orange", "banana", "blueberry", "apple"],
            )

    def test_nulls_in_frame(self):
        """ sankey raises a NullsInFrame when left or right data is null"""
        with self.assertRaises(NullsInFrame):
            sankey([None], self.data["predicted"])



# -*- coding: utf-8 -*-

import os
import unittest

import pandas as pd


class GenericTest(unittest.TestCase):

    """ Generic tests for sankey

    If figure_name is used, the resulting images
    will be removed at the end of the tests. """

    @classmethod
    def setUpClass(cls):
        cls.figure_name = ""
        cls.data = ""
        cls.colorDict = ""

    def tearDown(self):
        path = "{}.png".format(self.figure_name)
        # Comment this to check the resulting image
        if os.path.exists(path):
            os.remove(path)


class TestFruit(GenericTest):

    """ Base test to test with the data in fruit.txt """

    def setUp(self):
        self.figure_name = "fruit"
        self.data = pd.read_csv(
            "pysankey/fruits.txt", sep=" ", names=["true", "predicted"]
        )
        self.colorDict = {
            "apple": "#f71b1b",
            "blueberry": "#1b7ef7",
            "banana": "#f3f71b",
            "lime": "#12e23f",
            "orange": "#f78c1b",
            "kiwi": "#9BD937",
        }


class TestCustomerGood(GenericTest):

    """ Base test to test with the data in customers-goods.csv """

    def setUp(self):
        self.figure_name = "customer-good"
        self.data = pd.read_csv(
            "pysankey/customers-goods.csv",
            sep=",",
            names=["id", "customer", "good", "revenue"],
        )



# -*- coding: utf-8 -*-

import matplotlib.pyplot as plt

from pysankey import sankey
from pysankey.tests.generic_test import TestFruit


class TestSankey(TestFruit):
    def test_right_color(self):
        ax = sankey(self.data["true"], self.data["predicted"], rightColor=True)
        self.assertIsInstance(ax, plt.Axes)



# -*- coding: utf-8 -*-

from pysankey import sankey
from pysankey.tests.generic_test import TestFruit


class TestErrorCase(TestFruit):

    """ Test sankey's deprecation warnings. """

    def test_deprecated_parameters(self):
        """ Test if deprecation warnings are correctly triggered """
        with self.assertWarns(DeprecationWarning):
            sankey(
                self.data["true"],
                self.data["predicted"],
                colorDict=self.colorDict,
                figureName=self.figure_name,
            )

        with self.assertWarns(DeprecationWarning):
            sankey(
                self.data["true"],
                self.data["predicted"],
                colorDict=self.colorDict,
                closePlot=True,
            )

        with self.assertWarns(DeprecationWarning):
            sankey(
                self.data["true"],
                self.data["predicted"],
                colorDict=self.colorDict,
                figSize=(8, 8),
            )



# -*- coding: utf-8 -*-

import matplotlib.pyplot as plt

from pysankey import sankey
from pysankey.tests.generic_test import TestFruit, TestCustomerGood


class TestReadmeFruit(TestFruit):

    """ Test use case from README with the data in fruit.txt"""

    def test_no_fail_readme(self):
        ax = sankey(
            self.data["true"],
            self.data["predicted"],
            aspect=20,
            colorDict=self.colorDict,
            fontsize=12,
        )
        self.assertIsInstance(ax, plt.Axes)


class TestReadmeCustomerGood(TestCustomerGood):

    """ Test use case from README with the data in customer-goods.csv"""

    def test_no_fail_readme(self):
        weight = self.data["revenue"].values[1:].astype(float)
        ax = sankey(
            left=self.data["customer"].values[1:],
            right=self.data["good"].values[1:],
            rightWeight=weight,
            leftWeight=weight,
            aspect=20,
            fontsize=10,
        )
        self.assertIsInstance(ax, plt.Axes)
